pycot - Python Cursor on Target Module
**************************************

Renders and Parses Cursor on Target XML events.


Installation
============
Install from pypi using pip: ``pip install pycot``


Build Status
============

Master:

.. image:: https://travis-ci.org/ampledata/pycot.svg?branch=master
    :target: https://travis-ci.org/ampledata/pycot

Develop:

.. image:: https://travis-ci.org/ampledata/pycot.svg?branch=develop
    :target: https://travis-ci.org/ampledata/pycot


Source
======
Github: https://github.com/ampledata/pycot

Author
======
Greg Albrecht W2GMD oss@undef.net

http://orionlabs.io/

Copyright
=========
Copyright 2020 Orion Labs, Inc.

License
=======
Apache License, Version 2.0. See LICENSE for details.
